complete -c target/release/fclones -n "__fish_use_subcommand" -l progress -d 'Override progress reporting, by default (=auto) only report when stderr is a terminal. Possible values: true, false, auto' -r -f -a "{auto	'',true	'',false	''}"
complete -c target/release/fclones -n "__fish_use_subcommand" -s q -l quiet
complete -c target/release/fclones -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c target/release/fclones -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "group" -d 'Produce a list of groups of identical files'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "link" -d 'Replace redundant files with links'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "dedupe" -d 'Deduplicate file data using native filesystem deduplication capabilities'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "remove" -d 'Remove redundant files'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "move" -d 'Move redundant files to the given directory'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "complete" -d 'Print shell completion script to stdout'
complete -c target/release/fclones -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s o -l output -d 'Write the report to a file instead of the standard output' -r -F
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s f -l format -d 'Set output file format' -r -f -a "{default	'',fdupes	'',csv	'',json	''}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s d -l depth -d 'Limit the recursion depth' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l transform -d 'Transform each file by the specified program before matching' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s n -l rf-over -d 'Search for over-replicated files with replication factor above the specified value' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l rf-under -d 'Search for under-replicated files with replication factor below the specified value' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s s -l min -d 'Minimum file size in bytes (inclusive)' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l max -d 'Maximum file size in bytes (inclusive)' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l max-prefix-size -d 'Maximum prefix size to check in bytes' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l max-suffix-size -d 'Maximum suffix size to check in bytes' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l name -d 'Include only file names matched fully by any of the given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l path -d 'Include only paths matched fully by any of the given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l exclude -d 'Ignore paths matched fully by any of the given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l hash-fn -d 'A hash function to use for computing file digests' -r -f -a "{metro	'',xxhash	'',blake3	'',sha256	'',sha512	'',sha3-256	'',sha3-512	''}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s t -l threads -d 'Set the sizes of thread-pools' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l base-dir -d 'Base directory to use when resolving relative input paths' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l stdin -d 'Read the list of input paths from the standard input instead of the arguments'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s . -l hidden -d 'Include hidden files'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s A -l no-ignore -d 'Do not ignore files matching patterns listed in `.gitignore` and `.fdignore`'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s L -l follow-links -d 'Follow symbolic links'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s H -l match-links -d 'Treat files reachable from multiple paths through links as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s S -l symbolic-links -d 'Don\'t ignore symbolic links to files'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s I -l isolate -d 'Don\'t count matching files found within the same directory argument as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s 1 -l one-fs -d 'Don\'t match files on different filesystems or devices'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l in-place -d 'Read the transform output from the same path as the transform input file'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l no-copy -d 'Don\'t copy the file to a temporary location before transforming, when `$IN` parameter is specified in the `--transform` command'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l unique -d 'Instead of searching for duplicates, search for unique files'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s i -l ignore-case -d 'Make pattern matching case-insensitive'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s x -l regex -d 'Expect patterns as Perl compatible regular expressions instead of Unix globs'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l skip-content-hash -d 'Skip the full contents hash step entirely'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -l cache -d 'Enable caching of file hashes'
complete -c target/release/fclones -n "__fish_seen_subcommand_from group" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s o -l output -d 'Write the `dry_run` report to a file instead of the standard output' -r -F
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s m -l modified-before -d 'Deduplicate only the files that were modified before the given time' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s n -l rf-over -d 'Keep at least n replicas untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l name -d 'Restrict the set of files that can be removed or replaced by links to files with the name matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l path -d 'Restrict the set of files that can be removed or replaced by links to files with the path matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l priority -d 'Set the priority for files to be removed or replaced by links' -r -f -a "{top	'Give higher priority to the files listed higher in the input file',bottom	'Give higher priority to the files listed lower in the input file',newest	'Give higher priority to the files with the most recent creation time',oldest	'Give higher priority to the files with the least recent creation time',most-recently-modified	'Give higher priority to the files with the most recent modification time',least-recently-modified	'Give higher priority to the files with the least recent modification time',most-recently-accessed	'Give higher priority to the files with the most recent access time',least-recently-accessed	'Give higher priority to the files with the least recent access time',most-recent-status-change	'Give higher priority to the files with the most recent status change',least-recent-status-change	'Give higher priority to the files with the least recent status change',most-nested	'Give higher priority to the files nested deeper in the directory tree',least-nested	'Give higher priority to the files nested shallower in the directory tree'}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l keep-name -d 'Keep files with names matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l keep-path -d 'Keep files with paths matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l isolate -d 'Specify a list of path prefixes. If non-empty, all duplicates having the same path prefix (root) are treated as one. This also means that the files sharing the same root can be either all dropped or all retained' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l dry-run -d 'Don\'t perform any changes on the file-system, but writes a log of file operations to the standard output'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s H -l match-links -d 'Treat files reachable from multiple paths through links as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l no-lock -d 'Don\'t lock files before performing an action on them'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -l no-check-size -d 'Allow the size of a file to be different than the size recorded during grouping'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s s -l soft -d 'Create soft (symbolic) links'
complete -c target/release/fclones -n "__fish_seen_subcommand_from link" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -s o -l output -d 'Write the `dry_run` report to a file instead of the standard output' -r -F
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -s m -l modified-before -d 'Deduplicate only the files that were modified before the given time' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -s n -l rf-over -d 'Keep at least n replicas untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l name -d 'Restrict the set of files that can be removed or replaced by links to files with the name matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l path -d 'Restrict the set of files that can be removed or replaced by links to files with the path matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l priority -d 'Set the priority for files to be removed or replaced by links' -r -f -a "{top	'Give higher priority to the files listed higher in the input file',bottom	'Give higher priority to the files listed lower in the input file',newest	'Give higher priority to the files with the most recent creation time',oldest	'Give higher priority to the files with the least recent creation time',most-recently-modified	'Give higher priority to the files with the most recent modification time',least-recently-modified	'Give higher priority to the files with the least recent modification time',most-recently-accessed	'Give higher priority to the files with the most recent access time',least-recently-accessed	'Give higher priority to the files with the least recent access time',most-recent-status-change	'Give higher priority to the files with the most recent status change',least-recent-status-change	'Give higher priority to the files with the least recent status change',most-nested	'Give higher priority to the files nested deeper in the directory tree',least-nested	'Give higher priority to the files nested shallower in the directory tree'}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l keep-name -d 'Keep files with names matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l keep-path -d 'Keep files with paths matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l isolate -d 'Specify a list of path prefixes. If non-empty, all duplicates having the same path prefix (root) are treated as one. This also means that the files sharing the same root can be either all dropped or all retained' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l dry-run -d 'Don\'t perform any changes on the file-system, but writes a log of file operations to the standard output'
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -s H -l match-links -d 'Treat files reachable from multiple paths through links as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l no-lock -d 'Don\'t lock files before performing an action on them'
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -l no-check-size -d 'Allow the size of a file to be different than the size recorded during grouping'
complete -c target/release/fclones -n "__fish_seen_subcommand_from dedupe" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -s o -l output -d 'Write the `dry_run` report to a file instead of the standard output' -r -F
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -s m -l modified-before -d 'Deduplicate only the files that were modified before the given time' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -s n -l rf-over -d 'Keep at least n replicas untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l name -d 'Restrict the set of files that can be removed or replaced by links to files with the name matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l path -d 'Restrict the set of files that can be removed or replaced by links to files with the path matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l priority -d 'Set the priority for files to be removed or replaced by links' -r -f -a "{top	'Give higher priority to the files listed higher in the input file',bottom	'Give higher priority to the files listed lower in the input file',newest	'Give higher priority to the files with the most recent creation time',oldest	'Give higher priority to the files with the least recent creation time',most-recently-modified	'Give higher priority to the files with the most recent modification time',least-recently-modified	'Give higher priority to the files with the least recent modification time',most-recently-accessed	'Give higher priority to the files with the most recent access time',least-recently-accessed	'Give higher priority to the files with the least recent access time',most-recent-status-change	'Give higher priority to the files with the most recent status change',least-recent-status-change	'Give higher priority to the files with the least recent status change',most-nested	'Give higher priority to the files nested deeper in the directory tree',least-nested	'Give higher priority to the files nested shallower in the directory tree'}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l keep-name -d 'Keep files with names matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l keep-path -d 'Keep files with paths matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l isolate -d 'Specify a list of path prefixes. If non-empty, all duplicates having the same path prefix (root) are treated as one. This also means that the files sharing the same root can be either all dropped or all retained' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l dry-run -d 'Don\'t perform any changes on the file-system, but writes a log of file operations to the standard output'
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -s H -l match-links -d 'Treat files reachable from multiple paths through links as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l no-lock -d 'Don\'t lock files before performing an action on them'
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -l no-check-size -d 'Allow the size of a file to be different than the size recorded during grouping'
complete -c target/release/fclones -n "__fish_seen_subcommand_from remove" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -s o -l output -d 'Write the `dry_run` report to a file instead of the standard output' -r -F
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -s m -l modified-before -d 'Deduplicate only the files that were modified before the given time' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -s n -l rf-over -d 'Keep at least n replicas untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l name -d 'Restrict the set of files that can be removed or replaced by links to files with the name matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l path -d 'Restrict the set of files that can be removed or replaced by links to files with the path matching any given patterns' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l priority -d 'Set the priority for files to be removed or replaced by links' -r -f -a "{top	'Give higher priority to the files listed higher in the input file',bottom	'Give higher priority to the files listed lower in the input file',newest	'Give higher priority to the files with the most recent creation time',oldest	'Give higher priority to the files with the least recent creation time',most-recently-modified	'Give higher priority to the files with the most recent modification time',least-recently-modified	'Give higher priority to the files with the least recent modification time',most-recently-accessed	'Give higher priority to the files with the most recent access time',least-recently-accessed	'Give higher priority to the files with the least recent access time',most-recent-status-change	'Give higher priority to the files with the most recent status change',least-recent-status-change	'Give higher priority to the files with the least recent status change',most-nested	'Give higher priority to the files nested deeper in the directory tree',least-nested	'Give higher priority to the files nested shallower in the directory tree'}"
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l keep-name -d 'Keep files with names matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l keep-path -d 'Keep files with paths matching any given patterns untouched' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l isolate -d 'Specify a list of path prefixes. If non-empty, all duplicates having the same path prefix (root) are treated as one. This also means that the files sharing the same root can be either all dropped or all retained' -r
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l dry-run -d 'Don\'t perform any changes on the file-system, but writes a log of file operations to the standard output'
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -s H -l match-links -d 'Treat files reachable from multiple paths through links as duplicates'
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l no-lock -d 'Don\'t lock files before performing an action on them'
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -l no-check-size -d 'Allow the size of a file to be different than the size recorded during grouping'
complete -c target/release/fclones -n "__fish_seen_subcommand_from move" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c target/release/fclones -n "__fish_seen_subcommand_from complete" -s h -l help -d 'Print help'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "group" -d 'Produce a list of groups of identical files'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "link" -d 'Replace redundant files with links'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "dedupe" -d 'Deduplicate file data using native filesystem deduplication capabilities'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove redundant files'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "move" -d 'Move redundant files to the given directory'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "complete" -d 'Print shell completion script to stdout'
complete -c target/release/fclones -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from group; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from dedupe; and not __fish_seen_subcommand_from remove; and not __fish_seen_subcommand_from move; and not __fish_seen_subcommand_from complete; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
